@@ -5,15 +5,13 @@ from typing import Literal, Optional
 import pydantic
 
 TYPES_SECTION = Literal[
-    "All",
-    "Early Years Pilot",
+    "EY Pilot",
     "Beavers",
-    "Beaver Scout",
-    "Cub Scout",
-    "Explorer Scouts",
-    "Scout",
-    "Scout Active Support",
-    "Scout Network",
+    "Cubs",
+    "Scouts",
+    "Explorers",
+    "Network",
+    "ASU",
     "Other",
 ]
 TYPES_UNIT_LEVELS = Literal["Group", "District", "County", "Region", "Country", "Organisation"]
@@ -25,12 +23,6 @@ class HierarchyBase(pydantic.BaseModel):
 
 class HierarchyUnit(HierarchyBase):
     name: str
-    parent_id: int
-
-    # metadata
-    status: Literal["ACT"]
-    address: str
-    member_count: int
 
 
 class HierarchySection(HierarchyUnit):
@@ -55,11 +47,14 @@ UnitData.update_forward_refs()  # NOTE: updating recursive/forward reference her
 DescendantData.update_forward_refs()  # NOTE: updating recursive/forward reference here!
 
 
-class HierarchyMember(pydantic.BaseModel):
+class HierarchyMemberID(pydantic.BaseModel):
     contact_number: int
+
+
+class HierarchyMember(HierarchyMemberID):
     name: Optional[str]
     role: Optional[str]
 
 
 class HierarchyUnitMembers(HierarchyBase):
-    member: list[HierarchyMember]
+    members: list[HierarchyMember]
